#!/bin/sh
#
# Copyright (c) 2004-2005 Poul-Henning Kamp.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
# $FreeBSD: head/tools/tools/nanobsd/Files/root/updatep2 205584 2010-03-24 11:21:33Z phk $
#
# Script to update partition 2 on a NanoBSD system.
#
# usage:
#	ssh somewhere cat image.s1 | sh updatep2
#

set -e

. /etc/nanobsd.conf

if mount | grep ${NANO_DRIVE}s2 > /dev/null ; then
	echo "You are running partition 2 already"
	echo "you probably want to use 'updatep1' instead"
	exit 1
fi

dev=$NANO_DRIVE
test -n "$NANO_LABEL" \
	&& dev=$(glabel status -s | grep "$NANO_DRIVE""s1a" | awk '{gsub("s1a",""); print $3}')

# Blow away old system.
dd if=/dev/zero of=/dev/${dev}s2 bs=1m count=1 > /dev/null 2>&1

# Copy in new system
dd of=/dev/${dev}s2 obs=64k

# Check that it worked
fsck_ffs -n /dev/${NANO_DRIVE}s2a

# Update the /etc/fstab
trap "umount /mnt" 1 2 15 EXIT
mount /dev/${NANO_DRIVE}s2a /mnt
sed -i "" "s/${NANO_DRIVE}s1/${NANO_DRIVE}s2/" /mnt/conf/base/etc/fstab
sed -i "" "s/${NANO_DRIVE}s1/${NANO_DRIVE}s2/" /mnt/etc/fstab
umount /mnt
trap 1 2 15 EXIT
gpart set -a active -i 2 ${dev}
